==> walkers-fabric-1.18.2-5.3.3-sources.jar: tocraft/walkers/ability/impl/specific/ShulkerAbility.java <==
package tocraft.walkers.ability.impl.specific;

import net.minecraft.class_1309;
import net.minecraft.class_1606;
import net.minecraft.class_1657;
import net.minecraft.class_1678;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_3417;
import net.minecraft.class_4051;
import tocraft.craftedcore.patched.CEntity;
import tocraft.walkers.ability.ShapeAbility;
import tocraft.walkers.mixin.accessor.ShulkerAccessor;

@SuppressWarnings("resource")
public class ShulkerAbility<T extends class_1606> extends ShapeAbility<T> {
    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        class_1309 target = CEntity.level(player).method_18468(CEntity.level(player).method_8390(class_1309.class, player.method_5829().method_1009(20, 4.0, 20), livingEntity -> true), class_4051.method_36625().method_18418(20).method_18420((livingEntity) -> !livingEntity.method_5779(player)), player, player.method_23317(), player.method_23320(), player.method_23321());

        if (target != null) {
            CEntity.level(player).method_8649(new class_1678(CEntity.level(player), player, target, player.method_5735().method_10166()));
        }
        player.method_5783(class_3417.field_15000, 2.0F, (player.method_6051().nextFloat() - player.method_6051().nextFloat()) * 0.2F + 1.0F);

        ((ShulkerAccessor) shape).callSetRawPeekAmount(100);
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8815;
    }

    @Override
    public int getDefaultCooldown() {
        return 80;
    }
}

==> walkers-fabric-1.19.4-5.2-sources.jar: tocraft/walkers/ability/impl/specific/ShulkerAbility.java <==
package tocraft.walkers.ability.impl.specific;

import net.minecraft.class_1309;
import net.minecraft.class_1606;
import net.minecraft.class_1657;
import net.minecraft.class_1678;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_3417;
import net.minecraft.class_4051;
import tocraft.craftedcore.patched.CEntity;
import tocraft.walkers.ability.ShapeAbility;
import tocraft.walkers.mixin.accessor.ShulkerAccessor;

@SuppressWarnings("resource")
public class ShulkerAbility<T extends class_1606> extends ShapeAbility<T> {
    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        class_1309 target = CEntity.level(player).method_18468(CEntity.level(player).method_8390(class_1309.class, player.method_5829().method_1009(20, 4.0, 20), livingEntity -> true), class_4051.method_36625().method_18418(20).method_18420((livingEntity) -> !livingEntity.method_5779(player)), player, player.method_23317(), player.method_23320(), player.method_23321());

        if (target != null) {
            CEntity.level(player).method_8649(new class_1678(CEntity.level(player), player, target, player.method_5735().method_10166()));
        }
        player.method_5783(class_3417.field_15000, 2.0F, (player.method_6051().method_43057() - player.method_6051().method_43057()) * 0.2F + 1.0F);

        ((ShulkerAccessor) shape).callSetRawPeekAmount(100);
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8815;
    }

    @Override
    public int getDefaultCooldown() {
        return 80;
    }
}
